==> agrosyst-web-1.5-sources.jar: fr/inra/agrosyst/web/actions/effective/EffectiveCropCycleDuplicate.java <==
package fr.inra.agrosyst.web.actions.effective;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: EffectiveCropCycleDuplicate.java 4461 2014-10-23 21:08:54Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/effective/EffectiveCropCycleDuplicate.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import com.google.common.base.Strings;

import fr.inra.agrosyst.api.services.effective.EffectiveCropCycleService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * @author David Cossé
 */
public class EffectiveCropCycleDuplicate extends AbstractAgrosystAction {

    private static final long serialVersionUID = 1L;
    
    protected String fromZoneId;

    protected String toZoneId;

    protected EffectiveCropCycleService effectiveCropCycleService;

    public void setEffectiveCropCycleService(EffectiveCropCycleService effectiveCropCycleService) {
        this.effectiveCropCycleService = effectiveCropCycleService;
    }

    public void setFromZoneId(String fromZoneId) {
        this.fromZoneId = fromZoneId;
    }

    public void setToZoneId(String toZoneId) {
        this.toZoneId = toZoneId;
    }

    public String getToZoneId() {
        return toZoneId;
    }

    @Override
    @Action(results = {
            @Result(name = SUCCESS, type = "redirectAction", params = {"actionName", "effective-crop-cycles-edit-input", "zoneTopiaId", "${toZoneId}"}),
            @Result(name = ERROR, type = "redirectAction", params = {"actionName", "effective-crop-cycles-list"})
    })
    public String execute() {
        if (Strings.isNullOrEmpty(fromZoneId) || Strings.isNullOrEmpty(toZoneId)) {
            notificationSupport.effectiveCropCycleNotDuplicable();
            return ERROR;
        }
        effectiveCropCycleService.duplicateEffectiveCropCycles(fromZoneId, toZoneId);
        notificationSupport.effectiveCropCycleDuplicate();
        return SUCCESS;
    }
}

==> agrosyst-web-1.5.1-sources.jar: fr/inra/agrosyst/web/actions/effective/EffectiveCropCycleDuplicate.java <==
package fr.inra.agrosyst.web.actions.effective;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: EffectiveCropCycleDuplicate.java 4461 2014-10-23 21:08:54Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/effective/EffectiveCropCycleDuplicate.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import com.google.common.base.Strings;

import fr.inra.agrosyst.api.services.effective.EffectiveCropCycleService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * @author David Cossé
 */
public class EffectiveCropCycleDuplicate extends AbstractAgrosystAction {

    private static final long serialVersionUID = 1L;
    
    protected String fromZoneId;

    protected String toZoneId;

    protected EffectiveCropCycleService effectiveCropCycleService;

    public void setEffectiveCropCycleService(EffectiveCropCycleService effectiveCropCycleService) {
        this.effectiveCropCycleService = effectiveCropCycleService;
    }

    public void setFromZoneId(String fromZoneId) {
        this.fromZoneId = fromZoneId;
    }

    public void setToZoneId(String toZoneId) {
        this.toZoneId = toZoneId;
    }

    public String getToZoneId() {
        return toZoneId;
    }

    @Override
    @Action(results = {
            @Result(name = SUCCESS, type = "redirectAction", params = {"actionName", "effective-crop-cycles-edit-input", "zoneTopiaId", "${toZoneId}"}),
            @Result(name = ERROR, type = "redirectAction", params = {"actionName", "effective-crop-cycles-list"})
    })
    public String execute() {
        if (Strings.isNullOrEmpty(fromZoneId) || Strings.isNullOrEmpty(toZoneId)) {
            notificationSupport.effectiveCropCycleNotDuplicable();
            return ERROR;
        }
        effectiveCropCycleService.duplicateEffectiveCropCycles(fromZoneId, toZoneId);
        notificationSupport.effectiveCropCycleDuplicate();
        return SUCCESS;
    }
}
